@@ -186,26 +186,26 @@ def read_classical_bayesian_from_hdf5_file(filename):
     :return: dictionary needed data
     """
     with h5py.File(filename, 'r') as h5f:
-        kwargs_mk_clf = {name: json.loads(h5f[name].value) for name in ["classifiers_fk", "classifiers_id"]}
-        kwargs_mk_clf["id2name"] = json.loads(h5f["band_names"].value)
+        kwargs_mk_clf = {name: json.loads(h5f[name][()]) for name in ["classifiers_fk", "classifiers_id"]}
+        kwargs_mk_clf["id2name"] = json.loads(h5f["band_names"][()])
 
-        kwargs_cb = {"bns": [h5f[name].value for name in json.loads(h5f["bns_names"].value)],
-                     "hh_full": h5f["hh_full"].value,
-                     "hh": {h5f["%s_key" % name].value: h5f["%s_value" % name].value for name in
-                            json.loads(h5f["hh_names"].value)},
-                     "hh_n": {key: value for key, value in zip(h5f["hh_n_keys"].value, h5f["hh_n_values"].value)},
-                     "n_bins": json.loads(h5f["n_bins"].value), "classes": h5f["classes"].value,
-                     "n_classes": json.loads(h5f["n_classes"].value),
-                     "bb_full": [h5f[name].value for name in json.loads(h5f["bb_full_names"].value)]}
+        kwargs_cb = {"bns": [h5f[name][()] for name in json.loads(h5f["bns_names"][()])],
+                     "hh_full": h5f["hh_full"][()],
+                     "hh": {h5f["%s_key" % name][()]: h5f["%s_value" % name][()] for name in
+                            json.loads(h5f["hh_names"][()])},
+                     "hh_n": {key: value for key, value in zip(h5f["hh_n_keys"][()], h5f["hh_n_values"][()])},
+                     "n_bins": json.loads(h5f["n_bins"][()]), "classes": h5f["classes"][()],
+                     "n_classes": json.loads(h5f["n_classes"][()]),
+                     "bb_full": [h5f[name][()] for name in json.loads(h5f["bb_full_names"][()])]}
 
         try:
-            mask_legend = {int(key): value for key, value in json.loads(h5f["mask_legend"].value).items()}
+            mask_legend = {int(key): value for key, value in json.loads(h5f["mask_legend"][()]).items()}
             mask_legend.update({value: key for key, value in mask_legend.items()})
         except KeyError:
             mask_legend = None
 
         try:
-            clf_to_col = {int(key): value for key, value in json.loads(h5f["clf_to_col"].value).items()}
+            clf_to_col = {int(key): value for key, value in json.loads(h5f["clf_to_col"][()]).items()}
         except KeyError:
             clf_to_col = None
 
@@ -386,8 +386,8 @@ class ClassicalBayesian(object):
             self.__in_bounds__(ii)
         pp = np.zeros((self.n_classes, len(ids[0])), dtype=np.float)
         for ii, cl in enumerate(self.classes):
-            hh = self.hh[cl][ids]
-            hh_full = self.hh_full[ids]
+            hh = self.hh[cl][tuple(ids)]
+            hh_full = self.hh_full[tuple(ids)]
             hh_valid = hh_full > 0.0
             pp[ii, hh_valid] = hh[hh_valid] / hh_full[hh_valid] / self.n_classes
 
