@@ -30,8 +30,8 @@ tables_origins += list(set(sys.path))
 sicor_downloads = {
     "cld_mask_S2_classi_20170412_v20170412_11:43:14.h5":
         ("google_drive", "0B2ygRjmN4hzNcC15Z2pPS2tQdTg"),
-    # "linear_atm_functions_ncwv_5_npre_4_ncoz_2_ntmp_2_wvl_350.0_2550.0_1.00_pca.h5":
-        # ("google_drive", "0B2ygRjmN4hzNRzhKZ3Z2V2FsWHM"),
+    "linear_atm_functions_ncwv_5_npre_4_ncoz_2_ntmp_2_wvl_350.0_2550.0_1.00_pca.h5":
+        ("google_drive", "0B2ygRjmN4hzNRzhKZ3Z2V2FsWHM"),
     "noclear_novelty_detector_channel2_difference9_0_index10_1_channel12_index1_8.retrain.pkl":
         ("google_drive", "0B2ygRjmN4hzNSHN2RG1lY0M4RW8")
 }
@@ -52,8 +52,8 @@ sicor_downloads_optional = {
 file_checksums = {
     "cld_mask_S2_classi_20170412_v20170412_11:43:14.h5":
         "b6d5189a694f25fe20f1ad664d465bcc",
-    # "linear_atm_functions_ncwv_5_npre_4_ncoz_2_ntmp_2_wvl_350.0_2550.0_1.00_pca.h5":
-        # "aaf6da6c4a4286500407c04e0feb043a",
+    "linear_atm_functions_ncwv_5_npre_4_ncoz_2_ntmp_2_wvl_350.0_2550.0_1.00_pca.h5":
+        "aaf6da6c4a4286500407c04e0feb043a",
     "noclear_novelty_detector_channel2_difference9_0_index10_1_channel12_index1_8.retrain.pkl":
         "d2e14b204ac7ee486a946a1c3bded467",
     "linear_atm_functions_ncwv_4_npre_2_ncoz_2_ntmp_1_nch4_4_wvl_350.0_2550.0_1.00_pca.h5":
@@ -108,9 +108,8 @@ def get_tables(sicor_table_path=None, sensor="s2", style="link", optional_downlo
     else:
         settings = os.path.join(os.path.dirname(options.__file__), "{sensor}_options.json".format(sensor=sensor))
     opts = get_options(settings)
-    # sicor_tables = set([op['atm_tables_fn'] for scat_type, op in opts["RTFO"].items()] +
-                       # [opts['cld_mask']["persistence_file"], opts['cld_mask']["novelty_detector"]])
-    sicor_tables = ([opts['cld_mask']["persistence_file"], opts['cld_mask']["novelty_detector"]])
+    sicor_tables = set([op['atm_tables_fn'] for scat_type, op in opts["RTFO"].items()] +
+                       [opts['cld_mask']["persistence_file"], opts['cld_mask']["novelty_detector"]])
     sicor_tables_fn = {os.path.basename(fn) for fn in sicor_tables}  # sicor tables, only basename of path in opts
 
     if optional_downloads is not None:
